@@ -8,7 +8,9 @@ logging.basicConfig(stream=sys.stdout, level=logging.DEBUG)
 
 
 def scan_host(ip_addr, start_port, end_port):
-    check_arguments(ip_addr, start_port, end_port)
+    status_check = check_arguments(ip_addr, start_port, end_port)
+    if status_check == False:
+        return
     logging.info('[*] Starting TCP port scan on host %s' % ip_addr)
     # Begin TCP scan on host
     tcp_scan(ip_addr, start_port, end_port)
@@ -16,7 +18,9 @@ def scan_host(ip_addr, start_port, end_port):
 
 
 def scan_range(network, start_port, end_port):
-    check_arguments(network + ".1", start_port, end_port)
+    status_check = check_arguments(network + ".1", start_port, end_port)
+    if status_check == False:
+        return
     logging.info('[*] Starting TCP port scan on network %s.0' % network)
     for host in range(1, 255):
         ip = network + '.' + str(host)
@@ -40,14 +44,18 @@ def check_arguments(ip_addr, start_port, end_port):
         ipaddress.ip_address(ip_addr)
     except ValueError:
         logging.error("Argument 1 not a valid IP address.")
+        return False
 
     try:
         x = int(start_port)
     except ValueError:
         logging.error("Argument 2 not a valid port number.")
+        return False
 
     try:
         y = int(end_port)
     except ValueError:
         logging.error("Argument 3 not a valid port number.")
+        return False
     logging.info("Star-Scan arguments valid, starting scan.")
+    return True
